import { HttpApi } from "./HttpApi";
/***
 * LiskClient is a client for the Lisk Core Websocket and HTTP protocol.
 * It maintains a Websocket connection and can call various HTTP endpoints.
 */
export declare class LiskClient {
    readonly http: HttpApi;
    options: {
        hostname: string;
        port: number;
        httpPort: number;
        query: {};
        connectTimeout: number;
        ackTimeout: number;
        pingTimeout: number;
        autoConnect: boolean;
        autoReconnect: boolean;
        autoReconnectOptions: {
            multiplier: number;
            initialDelay: number;
        };
    };
    private socket;
    constructor(hostname: string, wsPort: number, httpPort: number, query: object);
    connect(connectHandler: () => void, closeHandler: () => void, errorHandler: (error: any) => void): void;
    destroy(): void;
    getStatus(): Promise<NodeStatus>;
    getPeers(): Promise<WsPeerResponse>;
    getBlocks(lasBlockId?: string): Promise<WsBlockResponse>;
}
export declare type NodeStatus = {
    success: boolean;
    height: number;
    broadhash: string;
    nonce: string;
    httpPort: number;
    version: string;
    os: string;
};
export interface WsBlock {
    b_id: string;
    b_version: number;
    b_timestamp: number;
    b_height: number;
    b_previousBlock: string;
    b_numberOfTransactions: number;
    b_totalAmount: string;
    b_totalFee: string;
    b_reward: string;
    b_payloadLength: number;
    b_payloadHash: string;
    b_generatorPublicKey: string;
    b_blockSignature: string;
    t_id: string;
    t_rowId?: number;
    t_type?: number;
    t_timestamp?: number;
    t_senderPublicKey: string;
    t_senderId: string;
    t_recipientId: string;
    t_amount: string;
    t_fee: string;
    t_signature: string;
    t_signSignature?: any;
    s_publicKey?: any;
    d_username: string;
    v_votes: string;
    m_min?: any;
    m_lifetime?: any;
    m_keysgroup?: any;
    dapp_name?: any;
    dapp_description?: any;
    dapp_tags?: any;
    dapp_type?: any;
    dapp_link?: any;
    dapp_category?: any;
    dapp_icon?: any;
    in_dappId?: any;
    ot_dappId?: any;
    ot_outTransactionId?: any;
    t_requesterPublicKey?: any;
    tf_data?: any;
    t_signatures?: any;
}
export interface WsBlockResponse {
    blocks: WsBlock[];
}
export interface WsPeerResponse {
    success: boolean;
    peers: PeerInfo[];
}
export interface PeerInfo {
    ip: string;
    httpPort: number;
    wsPort: number;
    nonce: string;
    version: string;
    state?: number;
    os?: string;
    broadhash?: string;
    height?: number;
    updated?: any;
}
