/// <reference types="node" />
import * as events from "events";
import { LiskClient, NodeStatus, PeerInfo } from "./LiskClient";
export declare enum LiskPeerEvent {
    statusUpdated = "STATUS_UPDATED",
    peersUpdated = "PEERS_UPDATED",
    nodeStuck = "NODE_STUCK"
}
export declare enum PeerState {
    ONLINE = 0,
    OFFLINE = 1
}
export interface PeerOptions {
    ip: string;
    wsPort: number;
    httpPort: number;
    nonce: string;
    nethash: string;
    ownWSPort: number;
    ownHttpPort: number;
}
/***
 * LiskPeer is a wrapper for LiskClient that automatically updates the node status and keeps track of the connection
 * and checks whether the node is sane (not stuck)
 */
export declare class LiskPeer extends events.EventEmitter {
    readonly _options: PeerOptions;
    readonly ownNonce: string;
    readonly ownVersion: string;
    client: LiskClient;
    peers: PeerInfo[];
    knownBy: number;
    private _lastHeightUpdate;
    private _stuck;
    private statusUpdateInterval;
    constructor(_options: PeerOptions, ownNonce: string, ownVersion: string);
    private _state;
    readonly state: PeerState;
    private _status;
    readonly status: NodeStatus | undefined;
    private _httpActive;
    readonly httpActive: boolean;
    private _wsServerConnected;
    readonly wsServerConnected: boolean;
    readonly options: PeerOptions;
    /***
     * Handles new NodeStatus received from the Peer
     * Updates sync status and triggers events in case the node is stuck
     * @param {NodeStatus} status
     */
    handleStatusUpdate(status: NodeStatus): void;
    /***
     * Set the connection status of the websocket connection for this peer
     * @param {boolean} connected
     */
    setWebsocketServerConnected(connected: boolean): void;
    /***
     * Destroy the peer and close/destroy the associated socket
     * This does not close the incoming socket connection
     */
    destroy(): void;
    requestBlocks(): void;
    private onClientConnect;
    private onClientDisconnect;
    private onClientError;
    /***
     * Trigger a status update
     * Updates the node status, connected peers
     */
    private updateStatus;
}
